@@ -10,9 +10,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from collections.abc import Generator, Sequence
+import importlib.metadata
 import logging
 import sys
 import textwrap
+from typing import Any
 import warnings
 import yaml
 
@@ -25,56 +28,59 @@ from oslo_policy import policy
 LOG = logging.getLogger(__name__)
 
 GENERATOR_OPTS = [
-    cfg.StrOpt('output-file',
-               help='Path of the file to write to. Defaults to stdout.'),
-    cfg.BoolOpt('exclude-deprecated',
-                default=False,
-                help='If True, exclude deprecated entries from the generated '
-                     'output.'),
+    cfg.StrOpt(
+        'output-file', help='Path of the file to write to. Defaults to stdout.'
+    ),
+    cfg.BoolOpt(
+        'exclude-deprecated',
+        default=False,
+        help='If True, exclude deprecated entries from the generated output.',
+    ),
 ]
 
 RULE_OPTS = [
-    cfg.MultiStrOpt('namespace',
-                    help='Option namespace(s) under "oslo.policy.policies" in '
-                         'which to query for options.'),
-    cfg.StrOpt('format',
-               deprecated_for_removal=True,
-               deprecated_since='Victoria',
-               deprecated_reason="""
-``policy_file`` support for JSON formatted file is deprecated.
-So these tools also deprecate the support of generating or
-upgrading policy file in JSON format.
-""",
-               help='Desired format for the output.',
-               default='yaml',
-               choices=['json', 'yaml']),
+    cfg.MultiStrOpt(
+        'namespace',
+        help='Option namespace(s) under "oslo.policy.policies" in '
+        'which to query for options.',
+    ),
 ]
 
 ENFORCER_OPTS = [
-    cfg.StrOpt('namespace',
-               help='Option namespace under "oslo.policy.enforcer" in '
-                    'which to look for a policy.Enforcer.'),
+    cfg.StrOpt(
+        'namespace',
+        help='Option namespace under "oslo.policy.enforcer" in '
+        'which to look for a policy.Enforcer.',
+    ),
 ]
 
 UPGRADE_OPTS = [
-    cfg.StrOpt('policy',
-               required=True,
-               help='Path to the policy file which need to be updated.')
+    cfg.StrOpt(
+        'policy',
+        required=True,
+        help='Path to the policy file which need to be updated.',
+    )
 ]
 
 CONVERT_OPTS = [
-    cfg.MultiStrOpt('namespace',
-                    required=True,
-                    help='Option namespace(s) under "oslo.policy.policies" in '
-                         'which to query for options.'),
-    cfg.StrOpt('policy-file',
-               required=True,
-               help='Path to the policy file which need to be converted to '
-                    'yaml format.')
+    cfg.MultiStrOpt(
+        'namespace',
+        required=True,
+        help='Option namespace(s) under "oslo.policy.policies" in '
+        'which to query for options.',
+    ),
+    cfg.StrOpt(
+        'policy-file',
+        required=True,
+        help='Path to the policy file which need to be converted to '
+        'yaml format.',
+    ),
 ]
 
 
-def get_policies_dict(namespaces):
+def get_policies_dict(
+    namespaces: Sequence[str],
+) -> dict[str, list[policy.RuleDefault]]:
     """Find the options available via the given namespaces.
 
     :param namespaces: a list of namespaces registered under
@@ -82,36 +88,44 @@ def get_policies_dict(namespaces):
     :returns: a dict of {namespace1: [rule_default_1, rule_default_2],
                          namespace2: [rule_default_3]...}
     """
+    mgr: stevedore.named.NamedExtensionManager[list[policy.RuleDefault]]
     mgr = stevedore.named.NamedExtensionManager(
         'oslo.policy.policies',
         names=namespaces,
         on_load_failure_callback=on_load_failure_callback,
-        invoke_on_load=True)
+        invoke_on_load=True,
+    )
     opts = {ep.name: ep.obj for ep in mgr}
 
-    return opts
+    # we know the values of this dict are non-None due to invoke_on_load=True
+    return opts  # type: ignore
 
 
-def _get_enforcer(namespace):
+def _get_enforcer(namespace: str) -> policy.Enforcer:
     """Find a policy.Enforcer via an entry point with the given namespace.
 
     :param namespace: a namespace under oslo.policy.enforcer where the desired
                       enforcer object can be found.
     :returns: a policy.Enforcer object
     """
+    mgr: stevedore.named.NamedExtensionManager[policy.Enforcer]
     mgr = stevedore.named.NamedExtensionManager(
         'oslo.policy.enforcer',
         names=[namespace],
         on_load_failure_callback=on_load_failure_callback,
-        invoke_on_load=True)
+        invoke_on_load=True,
+    )
     if namespace not in mgr:
-        raise KeyError('Namespace "%s" not found.' % namespace)
+        raise KeyError(f'Namespace "{namespace}" not found.')
     enforcer = mgr[namespace].obj
 
+    # we know this will always be non-None due to invoke_on_load=True
+    assert enforcer is not None  # narrow type
+
     return enforcer
 
 
-def _format_help_text(description):
+def _format_help_text(description: str | None) -> str:
     """Format a comment for a policy based on the description provided.
 
     :param description: A string with helpful text.
@@ -120,12 +134,13 @@ def _format_help_text(description):
     if not description:
         return '#'
 
-    formatted_lines = []
-    paragraph = []
+    formatted_lines: list[str] = []
+    paragraph: list[str] = []
 
-    def _wrap_paragraph(lines):
-        return textwrap.wrap(' '.join(lines), 70, initial_indent='# ',
-                             subsequent_indent='# ')
+    def _wrap_paragraph(lines: Sequence[str]) -> list[str]:
+        return textwrap.wrap(
+            ' '.join(lines), 70, initial_indent='# ', subsequent_indent='# '
+        )
 
     for line in description.strip().splitlines():
         if not line.strip():
@@ -146,13 +161,14 @@ def _format_help_text(description):
                 warnings.warn(
                     'Invalid policy description: literal blocks must be '
                     'preceded by a new line. This will raise an exception in '
-                    'a future version of oslo.policy:\n%s' % description,
-                    FutureWarning)
+                    f'a future version of oslo.policy:\n{description}',
+                    FutureWarning,
+                )
                 formatted_lines.extend(_wrap_paragraph(paragraph))
                 formatted_lines.append('#')
                 paragraph = []
 
-            formatted_lines.append('# %s' % line.rstrip())
+            formatted_lines.append(f'# {line.rstrip()}')
 
     if paragraph:
         # dump anything we might still have in the buffer
@@ -161,8 +177,12 @@ def _format_help_text(description):
     return '\n'.join(formatted_lines)
 
 
-def _format_rule_default_yaml(default, include_help=True, comment_rule=True,
-                              add_deprecated_rules=True):
+def _format_rule_default_yaml(
+    default: policy.RuleDefault,
+    include_help: bool = True,
+    comment_rule: bool = True,
+    add_deprecated_rules: bool = True,
+) -> str:
     """Create a yaml node from policy.RuleDefault or policy.DocumentedRuleDefault.
 
     :param default: A policy.RuleDefault or policy.DocumentedRuleDefault object
@@ -173,99 +193,79 @@ def _format_rule_default_yaml(default, include_help=True, comment_rule=True,
                                  text.
     :returns: A string containing a yaml representation of the RuleDefault
     """  # noqa: E501
-    text = ('"%(name)s": "%(check_str)s"\n' %
-            {'name': default.name,
-             'check_str': default.check_str})
+    text = f'"{default.name}": "{default.check_str}"\n'
 
     if include_help:
-        op = ""
+        op = ''
         if hasattr(default, 'operations'):
             for operation in default.operations:
                 if operation['method'] and operation['path']:
-                    op += ('# %(method)s  %(path)s\n' %
-                           {'method': operation['method'],
-                            'path': operation['path']})
-        intended_scope = ""
-        if getattr(default, 'scope_types', None) is not None:
+                    op += '# {method}  {path}\n'.format(
+                        method=operation['method'],
+                        path=operation['path'],
+                    )
+        intended_scope = ''
+        if default.scope_types is not None:
             intended_scope = (
                 '# Intended scope(s): ' + ', '.join(default.scope_types) + '\n'
             )
         comment = '#' if comment_rule else ''
-        text = ('%(op)s%(scope)s%(comment)s%(text)s\n' %
-                {'op': op,
-                 'scope': intended_scope,
-                 'comment': comment,
-                 'text': text})
+        text = f'{op}{intended_scope}{comment}{text}\n'
         if default.description:
             text = _format_help_text(default.description) + '\n' + text
 
     if add_deprecated_rules and default.deprecated_for_removal:
         text = (
-            '# DEPRECATED\n# "%(name)s" has been deprecated since '
-            '%(since)s.\n%(reason)s\n%(text)s'
-        ) % {'name': default.name,
-             'since': default.deprecated_since,
-             'reason': _format_help_text(default.deprecated_reason),
-             'text': text}
+            f'# DEPRECATED\n# "{default.name}" has been deprecated since '
+            f'{default.deprecated_since}.\n'
+            f'{_format_help_text(default.deprecated_reason)}\n{text}'
+        )
     elif add_deprecated_rules and default.deprecated_rule:
         deprecated_reason = (
-            default.deprecated_rule.deprecated_reason or
-            default.deprecated_reason
+            default.deprecated_rule.deprecated_reason
+            or default.deprecated_reason
         )
         deprecated_since = (
-            default.deprecated_rule.deprecated_since or
-            default.deprecated_since
+            default.deprecated_rule.deprecated_since
+            or default.deprecated_since
         )
 
         # This issues a deprecation warning but aliases the old policy name
         # with the new policy name for compatibility.
         deprecated_text = (
-            '"%(old_name)s":"%(old_check_str)s" has been deprecated '
-            'since %(since)s in favor of "%(name)s":"%(check_str)s".'
-        ) % {
-            'old_name': default.deprecated_rule.name,
-            'old_check_str': default.deprecated_rule.check_str,
-            'since': deprecated_since,
-            'name': default.name,
-            'check_str': default.check_str,
-        }
-        text = '{text}# DEPRECATED\n{deprecated_text}\n{reason}\n'.format(
-            text=text,
-            reason=_format_help_text(deprecated_reason),
-            deprecated_text=_format_help_text(deprecated_text)
+            f'"{default.deprecated_rule.name}":"{default.deprecated_rule.check_str}" has been deprecated '  # noqa: E501
+            f'since {deprecated_since} in favor of "{default.name}":"{default.check_str}".'  # noqa: E501
+        )
+        text = (
+            f'{text}# DEPRECATED\n{_format_help_text(deprecated_text)}\n'
+            f'{_format_help_text(deprecated_reason)}\n'
         )
 
         if default.name != default.deprecated_rule.name:
-            text += ('# WARNING: A rule name change has been identified.\n'
-                     '#          This may be an artifact of new rules being\n'
-                     '#          included which require legacy fallback\n'
-                     '#          rules to ensure proper policy behavior.\n'
-                     '#          Alternatively, this may just be an alias.\n'
-                     '#          Please evaluate on a case by case basis\n'
-                     '#          keeping in mind the format for aliased\n'
-                     '#          rules is:\n'
-                     '#          "old_rule_name": "new_rule_name".\n')
-            text += ('# "%(old_name)s": "rule:%(name)s"\n' %
-                     {'old_name': default.deprecated_rule.name,
-                      'name': default.name})
+            text += (
+                '# WARNING: A rule name change has been identified.\n'
+                '#          This may be an artifact of new rules being\n'
+                '#          included which require legacy fallback\n'
+                '#          rules to ensure proper policy behavior.\n'
+                '#          Alternatively, this may just be an alias.\n'
+                '#          Please evaluate on a case by case basis\n'
+                '#          keeping in mind the format for aliased\n'
+                '#          rules is:\n'
+                '#          "old_rule_name": "new_rule_name".\n'
+            )
+            text += (
+                f'# "{default.deprecated_rule.name}": "rule:{default.name}"\n'
+            )
         text += '\n'
 
     return text
 
 
-def _format_rule_default_json(default):
-    """Create a json node from policy.RuleDefault or policy.DocumentedRuleDefault.
-
-    :param default: A policy.RuleDefault or policy.DocumentedRuleDefault object
-    :returns: A string containing a json representation of the RuleDefault
-    """  # noqa: E501
-    return ('"%(name)s": "%(check_str)s"' %
-            {'name': default.name,
-             'check_str': default.check_str})
-
-
-def _sort_and_format_by_section(policies, output_format='yaml',
-                                include_help=True, exclude_deprecated=False):
+def _sort_and_format_by_section(
+    policies: dict[str, list[policy.RuleDefault]],
+    include_help: bool = True,
+    exclude_deprecated: bool = False,
+) -> Generator[str, None, None]:
     """Generate a list of policy section texts
 
     The text for a section will be created and returned one at a time. The
@@ -276,25 +276,28 @@ def _sort_and_format_by_section(policies, output_format='yaml',
 
     :param policies: A dict of {section1: [rule_default_1, rule_default_2],
                                 section2: [rule_default_3]}
-    :param output_format: The format of the file to output to.
+    :param include_help: True, generates a sample-policy file with help text
+                         along with rules in which everything is commented out.
+                         False, generates a sample-policy file with only rules.
     :param exclude_deprecated: If to exclude deprecated policy rule entries,
                                defaults to False.
     """
     for section in sorted(policies.keys()):
         rule_defaults = policies[section]
         for rule_default in rule_defaults:
-            if output_format == 'yaml':
-                yield _format_rule_default_yaml(
-                    rule_default,
-                    include_help=include_help,
-                    add_deprecated_rules=not exclude_deprecated)
-            elif output_format == 'json':
-                LOG.warning(policy.WARN_JSON)
-                yield _format_rule_default_json(rule_default)
+            yield _format_rule_default_yaml(
+                rule_default,
+                include_help=include_help,
+                add_deprecated_rules=not exclude_deprecated,
+            )
 
 
-def _generate_sample(namespaces, output_file=None, output_format='yaml',
-                     include_help=True, exclude_deprecated=False):
+def _generate_sample(
+    namespaces: list[str],
+    output_path: str | None = None,
+    include_help: bool = True,
+    exclude_deprecated: bool = False,
+) -> None:
     """Generate a sample policy file.
 
     List all of the policies available via the namespace specified in the
@@ -303,8 +306,7 @@ def _generate_sample(namespaces, output_file=None, output_format='yaml',
     :param namespaces: a list of namespaces registered under
                        'oslo.policy.policies'. Stevedore will look here for
                        policy options.
-    :param output_file: The path of a file to output to. stdout used if None.
-    :param output_format: The format of the file to output to.
+    :param output_path: The path of a file to output to. stdout used if None.
     :param include_help: True, generates a sample-policy file with help text
                          along with rules in which everything is commented out.
                          False, generates a sample-policy file with only rules.
@@ -313,37 +315,34 @@ def _generate_sample(namespaces, output_file=None, output_format='yaml',
     """
     policies = get_policies_dict(namespaces)
 
-    output_file = (open(output_file, 'w') if output_file
-                   else sys.stdout)
+    output_file = open(output_path, 'w') if output_path else sys.stdout
 
     sections_text = []
     for section in _sort_and_format_by_section(
-            policies, output_format,
-            include_help=include_help,
-            exclude_deprecated=exclude_deprecated):
+        policies,
+        include_help=include_help,
+        exclude_deprecated=exclude_deprecated,
+    ):
         sections_text.append(section)
 
-    if output_format == 'yaml':
-        output_file.writelines(sections_text)
-    elif output_format == 'json':
-        LOG.warning(policy.WARN_JSON)
-        output_file.writelines((
-            '{\n    ',
-            ',\n    '.join(sections_text),
-            '\n}\n'))
+    output_file.writelines(sections_text)
 
     if output_file != sys.stdout:
         output_file.close()
 
 
-def _generate_policy(namespace, output_file=None, exclude_deprecated=False):
+def _generate_policy(
+    namespace: str,
+    output_path: str | None = None,
+    exclude_deprecated: bool = False,
+) -> None:
     """Generate a policy file showing what will be used.
 
     This takes all registered policies and merges them with what's defined in
     a policy file and outputs the result. That result is the effective policy
     that will be honored by policy checks.
 
-    :param output_file: The path of a file to output to. stdout used if None.
+    :param output_path: The path of a file to output to. stdout used if None.
     :param exclude_deprecated: If to exclude deprecated policy rule entries,
                                defaults to False.
     """
@@ -351,26 +350,29 @@ def _generate_policy(namespace, output_file=None, exclude_deprecated=False):
     # Ensure that files have been parsed
     enforcer.load_rules()
 
-    file_rules = [policy.RuleDefault(name, default.check_str)
-                  for name, default in enforcer.file_rules.items()]
-    registered_rules = [policy.RuleDefault(name, default.check_str)
-                        for name, default in enforcer.registered_rules.items()
-                        if name not in enforcer.file_rules]
+    file_rules = [
+        policy.RuleDefault(name, default.check_str)
+        for name, default in enforcer.file_rules.items()
+    ]
+    registered_rules = [
+        policy.RuleDefault(name, default.check_str)
+        for name, default in enforcer.registered_rules.items()
+        if name not in enforcer.file_rules
+    ]
     policies = {'rules': file_rules + registered_rules}
 
-    output_file = (open(output_file, 'w') if output_file
-                   else sys.stdout)
+    output_file = open(output_path, 'w') if output_path else sys.stdout
 
     for section in _sort_and_format_by_section(
-            policies, include_help=False,
-            exclude_deprecated=exclude_deprecated):
+        policies, include_help=False, exclude_deprecated=exclude_deprecated
+    ):
         output_file.write(section)
 
     if output_file != sys.stdout:
         output_file.close()
 
 
-def _list_redundant(namespace):
+def _list_redundant(namespace: str) -> None:
     """Generate a list of configured policies which match defaults.
 
     This checks all policies loaded from policy files and checks to see if they
@@ -393,7 +395,7 @@ def _list_redundant(namespace):
                 print(reg_rule)
 
 
-def _validate_policy(namespace):
+def _validate_policy(namespace: str) -> int:
     """Perform basic sanity checks on a policy file
 
     Checks for the following errors in the configured policy file:
@@ -422,7 +424,7 @@ def _validate_policy(namespace):
     enforcer.load_rules()
 
     if enforcer._informed_no_policy_file:
-        print('Configured policy file "%s" not found' % enforcer.policy_file)
+        print(f'Configured policy file "{enforcer.policy_file}" not found')
         # If the policy file is completely missing then the rest of our checks
         # don't make sense.
         return 1
@@ -451,7 +453,9 @@ def _validate_policy(namespace):
     return return_code
 
 
-def _convert_policy_json_to_yaml(namespace, policy_file, output_file=None):
+def _convert_policy_json_to_yaml(
+    namespace: str, policy_file: str, output_path: str | None = None
+) -> None:
     with open(policy_file) as rule_data:
         file_policies = jsonutils.loads(rule_data.read())
 
@@ -466,10 +470,7 @@ def _convert_policy_json_to_yaml(namespace, policy_file, output_file=None):
             # Some rules might be still RuleDefault object so let's prepare
             # empty 'operations' list and rule name as description for
             # those.
-            operations = [{
-                'method': '',
-                'path': ''
-            }]
+            operations: list[policy.Operation] = [{'method': '', 'path': ''}]
             if hasattr(default_rule, 'operations'):
                 operations = default_rule.operations
             # Converting JSON file rules to DocumentedRuleDefault rules so
@@ -485,22 +486,26 @@ def _convert_policy_json_to_yaml(namespace, policy_file, output_file=None):
                 default_rule.deprecated_for_removal,
                 default_rule.deprecated_reason,
                 default_rule.deprecated_since,
-                scope_types=default_rule.scope_types)
+                scope_types=default_rule.scope_types,
+            )
             if file_rule == default_rule:
                 rule_text = _format_rule_default_yaml(
-                    file_rule, add_deprecated_rules=False)
+                    file_rule, add_deprecated_rules=False
+                )
             else:
                 # NOTE(gmann): If json file rule is not same as default
                 # means rule is overridden then do not comment out it in
                 # yaml file.
                 rule_text = _format_rule_default_yaml(
-                    file_rule, comment_rule=False,
-                    add_deprecated_rules=False)
+                    file_rule, comment_rule=False, add_deprecated_rules=False
+                )
             yaml_format_rules.append(rule_text)
 
-    extra_rules_text = ("# WARNING: Below rules are either deprecated rules\n"
-                        "# or extra rules in policy file, it is strongly\n"
-                        "# recommended to switch to new rules.\n")
+    extra_rules_text = (
+        '# WARNING: Below rules are either deprecated rules\n'
+        '# or extra rules in policy file, it is strongly\n'
+        '# recommended to switch to new rules.\n'
+    )
     # NOTE(gmann): If policy json file still using the deprecated rules which
     # will not be present in default rules list. Or it can be case of any
     # extra rule (old rule which is now removed) present in json file.
@@ -509,23 +514,25 @@ def _convert_policy_json_to_yaml(namespace, policy_file, output_file=None):
     if file_policies:
         yaml_format_rules.append(extra_rules_text)
     for file_rule, check_str in file_policies.items():
-        rule_text = ('"%(name)s": "%(check_str)s"\n' %
-                     {'name': file_rule,
-                      'check_str': check_str})
+        rule_text = f'"{file_rule}": "{check_str}"\n'
         yaml_format_rules.append(rule_text)
 
-    if output_file:
-        with open(output_file, 'w') as fh:
+    if output_path:
+        with open(output_path, 'w') as fh:
             fh.writelines(yaml_format_rules)
     else:
         sys.stdout.writelines(yaml_format_rules)
 
 
-def on_load_failure_callback(*args, **kwargs):
+def on_load_failure_callback(
+    em: stevedore.ExtensionManager[Any],
+    ep: importlib.metadata.EntryPoint,
+    err: BaseException,
+) -> None:
     raise
 
 
-def _check_for_namespace_opt(conf):
+def _check_for_namespace_opt(conf: cfg.ConfigOpts) -> None:
     # NOTE(bnemec): This opt is required, but due to lp#1849518 we need to
     # make it optional while our consumers migrate to the new method of
     # parsing cli args. Making the arg itself optional and explicitly checking
@@ -536,7 +543,9 @@ def _check_for_namespace_opt(conf):
         raise cfg.RequiredOptError('namespace', 'DEFAULT')
 
 
-def generate_sample(args=None, conf=None):
+def generate_sample(
+    args: Sequence[str] | None = None, conf: cfg.ConfigOpts | None = None
+) -> None:
     logging.basicConfig(level=logging.WARN)
     # Allow the caller to pass in a local conf object for unit testing
     if conf is None:
@@ -545,38 +554,51 @@ def generate_sample(args=None, conf=None):
     conf.register_opts(GENERATOR_OPTS + RULE_OPTS)
     conf(args)
     _check_for_namespace_opt(conf)
-    _generate_sample(conf.namespace, output_file=conf.output_file,
-                     output_format=conf.format,
-                     exclude_deprecated=conf.exclude_deprecated)
+    _generate_sample(
+        conf.namespace,
+        output_path=conf.output_file,
+        exclude_deprecated=conf.exclude_deprecated,
+    )
 
 
-def generate_policy(args=None):
+def generate_policy(args: list[str] | None = None) -> None:
     logging.basicConfig(level=logging.WARN)
     conf = cfg.CONF
     conf.register_cli_opts(GENERATOR_OPTS + ENFORCER_OPTS)
     conf.register_opts(GENERATOR_OPTS + ENFORCER_OPTS)
     conf(args)
     _check_for_namespace_opt(conf)
-    _generate_policy(conf.namespace, conf.output_file,
-                     conf.exclude_deprecated)
+    _generate_policy(conf.namespace, conf.output_file, conf.exclude_deprecated)
 
 
-def _upgrade_policies(policies, default_policies):
+def _upgrade_policies(
+    policies: dict[str, str],
+    default_policies: dict[str, list[policy.RuleDefault]],
+) -> None:
     old_policies_keys = list(policies.keys())
     for section in sorted(default_policies.keys()):
         rule_defaults = default_policies[section]
         for rule_default in rule_defaults:
-            if (rule_default.deprecated_rule and
-                    rule_default.deprecated_rule.name in old_policies_keys):
+            if (
+                rule_default.deprecated_rule
+                and rule_default.deprecated_rule.name in old_policies_keys
+            ):
                 policies[rule_default.name] = policies.pop(
-                    rule_default.deprecated_rule.name)
-                LOG.info('The name of policy %(old_name)s has been upgraded to'
-                         '%(new_name)',
-                         {'old_name': rule_default.deprecated_rule.name,
-                          'new_name': rule_default.name})
+                    rule_default.deprecated_rule.name
+                )
+                LOG.info(
+                    'The name of policy %(old_name)s has been upgraded to'
+                    '%(new_name)',
+                    {
+                        'old_name': rule_default.deprecated_rule.name,
+                        'new_name': rule_default.name,
+                    },
+                )
 
 
-def upgrade_policy(args=None, conf=None):
+def upgrade_policy(
+    args: list[str] | None = None, conf: cfg.ConfigOpts | None = None
+) -> None:
     logging.basicConfig(level=logging.WARN)
     # Allow the caller to pass in a local conf object for unit testing
     if conf is None:
@@ -593,21 +615,12 @@ def upgrade_policy(args=None, conf=None):
 
     if conf.output_file:
         with open(conf.output_file, 'w') as fh:
-            if conf.format == 'yaml':
-                yaml.safe_dump(policies, fh, default_flow_style=False)
-            elif conf.format == 'json':
-                LOG.warning(policy.WARN_JSON)
-                jsonutils.dump(policies, fh, indent=4)
+            yaml.safe_dump(policies, fh, default_flow_style=False)
     else:
-        if conf.format == 'yaml':
-            sys.stdout.write(yaml.safe_dump(policies,
-                                            default_flow_style=False))
-        elif conf.format == 'json':
-            LOG.warning(policy.WARN_JSON)
-            sys.stdout.write(jsonutils.dumps(policies, indent=4))
+        sys.stdout.write(yaml.safe_dump(policies, default_flow_style=False))
 
 
-def list_redundant(args=None):
+def list_redundant(args: list[str] | None = None) -> None:
     logging.basicConfig(level=logging.WARN)
     conf = cfg.CONF
     conf.register_cli_opts(ENFORCER_OPTS)
@@ -617,7 +630,7 @@ def list_redundant(args=None):
     _list_redundant(conf.namespace)
 
 
-def validate_policy(args=None):
+def validate_policy(args: list[str] | None = None) -> None:
     logging.basicConfig(level=logging.WARN)
     conf = cfg.CONF
     conf.register_cli_opts(ENFORCER_OPTS)
@@ -626,8 +639,11 @@ def validate_policy(args=None):
     sys.exit(_validate_policy(conf.namespace))
 
 
-def convert_policy_json_to_yaml(args=None, conf=None):
+def convert_policy_json_to_yaml(
+    args: list[str] | None = None, conf: cfg.ConfigOpts | None = None
+) -> None:
     logging.basicConfig(level=logging.WARN)
+    LOG.warning('The oslopolicy-convert-json-to-yaml tool is deprecated')
     # Allow the caller to pass in a local conf object for unit testing
     if conf is None:
         conf = cfg.CONF
@@ -635,5 +651,6 @@ def convert_policy_json_to_yaml(args=None, conf=None):
     conf.register_opts(GENERATOR_OPTS + CONVERT_OPTS)
     conf(args)
     _check_for_namespace_opt(conf)
-    _convert_policy_json_to_yaml(conf.namespace, conf.policy_file,
-                                 conf.output_file)
+    _convert_policy_json_to_yaml(
+        conf.namespace, conf.policy_file, conf.output_file
+    )
