@@ -27,11 +27,21 @@ class FixtureTestCase(test_base.PolicyBaseTestCase):
     def _test_enforce_http(self, return_value):
         self.useFixture(fixture.HttpCheckFixture(return_value=return_value))
         action = self.getUniqueString()
-        rules_json = {
-            action: "http:" + self.getUniqueString()
-        }
+        rules_json = {action: 'http:' + self.getUniqueString()}
         rules = oslo_policy.Rules.load(json.dumps(rules_json))
         self.enforcer.set_rules(rules)
-        return self.enforcer.enforce(rule=action,
-                                     target={},
-                                     creds={})
+        return self.enforcer.enforce(rule=action, target={}, creds={})
+
+    def test_enforce_https_true(self):
+        self.assertTrue(self._test_enforce_http(True))
+
+    def test_enforce_https_false(self):
+        self.assertFalse(self._test_enforce_http(False))
+
+    def _test_enforce_https(self, return_value):
+        self.useFixture(fixture.HttpsCheckFixture(return_value=return_value))
+        action = self.getUniqueString()
+        rules_json = {action: 'https:' + self.getUniqueString()}
+        rules = oslo_policy.Rules.load(json.dumps(rules_json))
+        self.enforcer.set_rules(rules)
+        return self.enforcer.enforce(rule=action, target={}, creds={})
